@@ -13,7 +13,7 @@ Uses data from www.thetvdb.com via tvdb_api
 """
 
 __author__ = "dbr/Ben"
-__version__ = "0.7"
+__version__ = "1.0"
 
 import os, sys, re
 from optparse import OptionParser
@@ -63,7 +63,7 @@ def findFiles(args, recursive = False, verbose = False):
     """
     Takes a list of files/folders, grabs files inside them. Does not recurse
     more than one level (if a folder is supplied, it will list files within),
-    unless recurse is True, in which case it will recursivly find all files.
+    unless recurse is True, in which case it will recursively find all files.
     """
     allfiles = []
     for cfile in args:
@@ -74,7 +74,8 @@ def findFiles(args, recursive = False, verbose = False):
                     allfiles.append(newpath)
                 else:
                     if recursive:
-                        if verbose: print "Recursivly scanning %s" % (newpath)
+                        if verbose:
+                            print "Recursively scanning %s" % (newpath)
                         allfiles.extend(
                             findFiles([newpath], recursive = recursive, verbose = verbose)
                         )
@@ -88,50 +89,52 @@ def findFiles(args, recursive = False, verbose = False):
     return allfiles
 #end findFiles
 
+def processSingleName(name, verbose=False):
+    filepath, filename = os.path.split(name)
+    filename, ext = os.path.splitext(filename)
+
+    # Remove leading . from extension
+    ext = ext.replace(".", "", 1)
+
+    for r in config['name_parse']:
+        match = r.match(filename)
+        if match:
+            seriesname, seasno, epno = match.groups()
+
+            #remove ._- characters from name (- removed only if next to end of line)
+            seriesname = re.sub("[\._]|\-(?=$)", " ", seriesname).strip()
+
+            seasno, epno = int(seasno), int(epno)
+
+            if verbose:
+                print "*"*20
+                print "File:", filename
+                print "Pattern:", r.pattern
+                print "Seriesname:", seriesname
+                print "Seas:", seasno
+                print "Ep:", epno
+                print "*"*20
+
+            return{'file_seriesname':seriesname,
+                   'seasno':seasno,
+                   'epno':epno,
+                   'filepath':filepath,
+                   'filename':filename,
+                   'ext':ext
+            }
+    else:
+        print "Invalid name: %s" % (name)
+    #end for r
+
 def processNames(names, verbose=False):
     """
     Takes list of names, runs them though the config['name_parse'] regexs
     """
     allEps = []
     for f in names:
-        filepath, filename = os.path.split( f )
-        filename, ext = os.path.splitext( filename )
-
-        # Remove leading . from extension
-        ext = ext.replace(".", "", 1)
-
-        for r in config['name_parse']:
-            match = r.match(filename)
-            if match:
-                seriesname, seasno, epno = match.groups()
-
-                #remove ._- characters from name (- removed only if next to end of line)
-                seriesname = re.sub("[\._]|\-(?=$)", " ", seriesname).strip()
-
-                seasno, epno = int(seasno), int(epno)
-
-                if verbose:
-                    print "*"*20
-                    print "File:", filename
-                    print "Pattern:", r.pattern
-                    print "Seriesname:", seriesname
-                    print "Seas:", seasno
-                    print "Ep:", epno
-                    print "*"*20
-
-                allEps.append({ 'file_seriesname':seriesname,
-                                'seasno':seasno,
-                                'epno':epno,
-                                'filepath':filepath,
-                                'filename':filename,
-                                'ext':ext
-                             })
-                break # Matched - to the next file!
-        else:
-            print "Invalid name: %s" % (f)
-        #end for r
-    #end for f
-
+        allEps.append(
+            processSingleName(f, verbose=verbose)
+        )
     return allEps
 #end processNames
 
